@@ -1,6 +1,6 @@
 from dataclasses import dataclass
 
-from iwf_api.models import WorkflowStopType
+from iwf.iwf_api.iwf_api.models import WorkflowStopType
 
 
 @dataclass
